/*******************************************************************************
 *	BoapnsD.h	Produced by Bidl
 *******************************************************************************
 */

#ifndef BOAPNSD_H
#define BOAPNSD_H 1

#include <Boap.h>

#include <BList.h>
#include <BArray.h>

namespace Boapns {
	class BoapEntry {
	public:
		BoapEntry();
		BoapEntry(BString pname, BString phostName, BList<BString> paddressList, UInt32 pport, UInt32 pservice);
	public:
		BString	name;
		BString	hostName;
		BList<BString>	addressList;
		UInt32	port;
		UInt32	service;
	};

}
#endif
