/*******************************************************************************
 *	TestcaseT.cc	Produced by Bidl
 *******************************************************************************
 */

#include <stdlib.h>
#include <stdint.h>
#include <TestcaseT.h>

using namespace Appliance;

LightServer::LightServer(BoapServer& server, BString name) : LightService(server, name){
}

BError LightServer::setLevel(Int32 level){
	BError	err;

	return err;
}

SwitchServer::SwitchServer(BoapServer& server, BString name) : SwitchService(server, name){
}

BError SwitchServer::swtchChanged(Int32 level){
	BError	err;

	return err;
}

TvServer::TvServer(BoapServer& server, BString name) : TvService(server, name){
}

BError TvServer::setChannel(Int32 channel){
	BError	err;

	return err;
}

TvRecorderServer::TvRecorderServer(BoapServer& server, BString name) : TvRecorderService(server, name){
}

BError TvRecorderServer::setChannel(Int32 channel){
	BError	err;

	return err;
}

