/*******************************************************************************
 *	Boapns		Boap Object access protocol
 *			T.Barnaby,	BEAM Ltd,	4/3/04
 *******************************************************************************
 */
module Appliance {
	interface Light {
		Error	setLevel(in Int32 level);
	};
	
	interface Switch {
		Error	swtchChanged(in Int32 level);
	};
	
	interface Tv {
		Error	setChannel(in Int32 channel);
	};
	interface TvRecorder {
		Error	setChannel(in Int32 channel);
	};
};
