/*******************************************************************************
 *	GenBDataMySql.h	Generate Data output
 *			T.Barnaby,	BEAM Ltd,	12/9/03
 *******************************************************************************
 */
#ifndef GENBDATAMYSQL_HH
#define GENBDATAMYSQL_HH

#include <Gen.h>

class GenBDataMySql : public Gen {
public:
			GenBDataMySql();
			~GenBDataMySql();
	BError		produce(Node* n, BString fileName);
private:
	BError		produceHeaderImp();
	BError		produceTrailerImp();
	BError		produceImp(Node* n);
	BString		getTypeName(BString typeName);
	BError		produceType(BString& s, BString name, Type* t);

	BString		ofileName;
	FileIndent	ofileImp;
	BString		omodule;
	int		otypeDomain;
	int		otypeNum;
};

#endif
