/*******************************************************************************
 *	TestT.cc	Produced by Bidl
 *******************************************************************************
 */

#include <stdlib.h>
#include <stdint.h>
#include <TestT.h>

using namespace Test;

Obj1Server::Obj1Server(BoapServer& server, BString name) : Obj1Service(server, name){
}

BError Obj1Server::setData(Int32 a1, Data a2){
	BError	err;

	return err;
}

BError Obj1Server::getData(Int32& a1, Data& a2){
	BError	err;

	return err;
}

BError Obj1Server::setData1(Int32 a1, BArray<Int32> a2){
	BError	err;

	return err;
}

BError Obj1Server::getData1(Int32& a1, BArray<Int32>& a2){
	BError	err;

	return err;
}

BError Obj1Server::setData2(Int32 a1, BArray<Data1> a2){
	BError	err;

	return err;
}

BError Obj1Server::getData2(Int32& a1, BArray<Data1>& a2){
	BError	err;

	return err;
}

BError Obj1Server::setData3(Int32 a1, BArray<Data> a2){
	BError	err;

	return err;
}

BError Obj1Server::getData3(Int32& a1, BArray<Data>& a2){
	BError	err;

	return err;
}

