/*******************************************************************************
 *	BIdl.h		BEAM IDL
 *			T.Barnaby, 	BEAM Ltd,	2/5/03
 *******************************************************************************
 */
#ifndef BIDL_H
#define BIDL_H	1

#include <stdio.h>
#include <Type.h>
#include <Node.h>

#define	YYSTYPE	Node*

/* External Defs */
extern FILE*		fileOut;
extern BString		fileName;
extern TypeList		gtypelist;
extern Node*		result;

#if DEBUG
#define dprintf(fmt, a...)	printf(fmt, ##a)
#else
#define dprintf(fmt, a...)
#endif
#endif
