//// General Comment
module Test {
	class DataValue {
		Int16		spare;			///< Spare data entry. Used to padd to 64bits
		Int16		sigma;			///< The Sigma value
		Int16		deltaX;			///< The DeltaX value
		Int16		deltaY;			///< The DeltaY value
	};

	struct Data {
		UInt32			num;
		Array<DataValue>	data;
	};
	
	interface Obj1 {
		Error setData(in Int32 a1);		///< Set some data
		Error getData(out Int32 a1);		///< Get some data

		Error setData1(in Int32 a1, in Data a2);	///< Set some data
//		Error setData1(in Int32 a1, inref Data a2);	///< Set some data
		Error getData1(out Int32 a1, out Data a2);	///< Get some data
	};
};
