/*******************************************************************************
 *	BTypes.h	Basic Types
 *			T.Barnaby,	BEAM Ltd,	1/4/05
 *******************************************************************************
 */
#ifndef BTYPES_H
#define BTYPES_H	1

#include <stdint.h>
#include <sys/types.h>
#include <vector>

typedef int8_t			BInt8;
typedef uint8_t			BUInt8;
typedef int16_t			BInt16;
typedef uint16_t		BUInt16;
typedef int32_t			BInt32;
typedef uint32_t		BUInt32;
typedef int64_t			BInt64;
typedef uint64_t		BUInt64;
typedef float			BFloat;
typedef double			BDouble;
typedef size_t			BSize;
typedef uint32_t		BUInt;
typedef std::vector<float>	BArrayFloat;
typedef std::vector<double>	BArrayDouble;

// For BOAP
typedef int8_t			Int8;
typedef uint8_t			UInt8;
typedef int16_t			Int16;
typedef uint16_t		UInt16;
typedef int32_t			Int32;
typedef uint32_t		UInt32;
typedef int64_t			Int64;
typedef uint64_t		UInt64;
typedef float			Float;
typedef double			Double;
#endif
